@@ -5,18 +5,19 @@ from genie_pkg import GenieException
 from typing import Tuple
 
 class Australia(object):
-    
-    """Provides random addresses from australia"""
+
+    """Provide random OZ address."""
 
     def __init__(self):
+        """Loads postcode data from repository."""
         self.data = json.loads(resource_string(__name__, 'data/oz_postcodes.json'))
-    
+
     def get_random_state(self) -> str:
         return one_of(list(self.data.keys()))
 
     def get_random_city_postcode(self, state) -> Tuple[str, str]:
         state_data = self.data[state]
-        post_codes = list(state_data.keys())      
+        post_codes = list(state_data.keys())
         pc = one_of(post_codes)
         locality = state_data[pc]["localities"]
         return (locality, pc)
@@ -24,7 +25,7 @@ class Australia(object):
     def get_city(self, state, postcode):
         localities = self.data[state][postcode]["localities"]
         return one_of(localities)
-        
+
     def get_random_geo_coordinate(self, state, postcode):
         center = self.data[state][postcode].get("center", {})
         if center:
