@@ -1,4 +1,3 @@
-import pandas_flavor as pf
 from lark import Lark, Tree, Token
 from pkg_resources import resource_string
 from typing import Tuple, List, Any
@@ -6,8 +5,9 @@ from genie_pkg import GenieException
 import numpy as np
 from dateutil.parser import parse
 import pandas as pd
+import typing
 
-@pf.register_dataframe_accessor('dqc')
+@pd.api.extensions.register_dataframe_accessor('dqc') # type: ignore
 class QualityChecker(object):
 
     """Monkeypatch pandas dataframe to provide quality checks."""
@@ -48,7 +48,7 @@ class QualityChecker(object):
         q = float(node.children[1])
         c = node.children[2]
         rhs = float(node.children[3])
-        lhs = self._obj[column_name].quantile(q)
+        lhs = self._obj[column_name].quantile(q) # type: ignore
         return node.data, column_name, self._comparator_to_fn(c, rhs)(lhs)
 
     @staticmethod
@@ -70,18 +70,12 @@ class QualityChecker(object):
         column_name = self._treat_column_name(node.children[0])
         pass_percent = 100
         ignore_nulls = False
-        if len(node.children) == 3:
-            pass_percent = int(node.children[1])
-            ignore_nulls = self._str_to_bool(node.children[2])
-
-        if len(node.children) == 2:
-            c = node.children[1]
+        for c in node.children:
             if c.type == 'PERCENT':
                 pass_percent = int(c.value)
             if c.type == 'BOOL':
                 ignore_nulls = self._str_to_bool(c.value)
 
-
         non_null_rows = self._obj[self._obj[column_name].notnull()]
         valid_dates = non_null_rows[non_null_rows[column_name].apply(self._is_date)]
         if not ignore_nulls:
@@ -98,12 +92,13 @@ class QualityChecker(object):
         allowed_values = [ct.value.replace("\"", "") for ct in node.children[1].children]
         unique_values = self._obj[column_name].unique()
         ignore_case = False
-        if len(node.children) == 3:
-            ignore_case = self._str_to_bool(node.children[2].value)
+        for c in node.children:
+            if not isinstance(c, Tree) and c.type == 'BOOL':
+                ignore_case = self._str_to_bool(c.value)
 
         if ignore_case:
             allowed_values = [v.lower() for v in allowed_values]
-            unique_values = [v.lower() for v in unique_values]
+            unique_values = [v.lower() for v in unique_values] # type: ignore
 
         return node.data, column_name, all(elem in allowed_values for elem in unique_values)
 
@@ -111,24 +106,15 @@ class QualityChecker(object):
         column_name = self._treat_column_name(node.children[0])
         pass_percent = 100
         ignore_nulls = False
-        if len(node.children) == 4:
-            # index 2 is "=="
-            c = node.children[1]
+        for c in node.children:
             if c.type == 'PERCENT':
                 pass_percent = int(c.value)
-            if c.type == 'BOOL':
+            elif c.type == 'BOOL':
                 ignore_nulls = self._str_to_bool(c.value)
-            rhs = int(node.children[3])
-        elif len(node.children) == 3:
-            # index 1 is "=="
-            rhs = int(node.children[2])
-        else:
-            pass_percent = int(node.children[1])
-            ignore_nulls = self._str_to_bool(node.children[2].value)
-            # index 3 is "=="
-            rhs = int(node.children[4])
+            elif c.type == 'SIGNED_NUMBER':
+                rhs = int(c.value)
 
-        self._obj['length'] = self._obj[column_name].fillna('').astype(str).map(len)
+        self._obj['length'] = self._obj[column_name].fillna('').astype(str).map(len) # type: ignore
         if ignore_nulls:
             not_na_df = self._obj.replace(r'^\s*$', np.NaN, regex=True).dropna()
         else:
@@ -147,21 +133,22 @@ class QualityChecker(object):
     def _apply_has_columns(self, node) -> Tuple[str, Any, bool]:
         column_names = [ct.value.replace("\"", "") for ct in node.children[0].children]
         ignore_case = False
-        if len(node.children) == 2:
-            ignore_case = self._str_to_bool(node.children[1].value)
+        for c in node.children:
+            if not isinstance(c, Tree) and c.type == 'BOOL':
+                ignore_case = self._str_to_bool(c.value)
 
         if ignore_case:
             expected_columns = [c.lower() for c in column_names]
             columns_in_df = list(map(str.lower, self._obj.columns))
         else:
             expected_columns = column_names
-            columns_in_df = self._obj.columns
+            columns_in_df = list(self._obj.columns)
 
         return node.data, ','.join(columns_in_df), len(set(columns_in_df).intersection(expected_columns)) == len(set(expected_columns))
 
     @staticmethod
     def _build_query(key_value_node: Tree):
-        splits = [ct.value.split(":") for ct in key_value_node.children]
+        splits = [ct.value.split(":") for ct in key_value_node.children] # type: ignore
         cleansed = [(s[0].replace("\"", "").strip(), s[1].replace("\"", "").strip()) for s in splits]
         return ' & '.join([f'{c[0]} == "{c[1]}"' for c in cleansed])
 
@@ -189,7 +176,7 @@ class QualityChecker(object):
                 return self._apply_has_columns(c)
             elif c.data == "is_unique":
                 column_name = self._treat_column_name(c.children[0])
-                return c.data, None, self._obj[column_name].is_unique
+                return c.data, None, self._obj[column_name].is_unique # type: ignore
             elif c.data == "not_null":
                 column_name = self._treat_column_name(c.children[0])
                 return c.data, None, self._obj[column_name].isna().sum() == 0
@@ -224,6 +211,8 @@ class QualityChecker(object):
                 raise GenieException('Unknown instruction: %s' % predicates.data)
         return results
 
+    # Adding this decorator as mypy cant work out lark tree
+    @typing.no_type_check
     def _run(self, pt: Tree) -> List[Tuple[str, Any, bool]]:
         if len(pt.children) != 1:
             raise GenieException('How is this possible: %s' % pt.children)
@@ -251,7 +240,7 @@ class QualityChecker(object):
         ast = self._parse_spec(check_spec)
         self.ignore_column_case = ignore_column_case
         if self.ignore_column_case:
-            self._obj.columns = map(str.lower, self._obj.columns)
+            self._obj.columns = map(str.lower, self._obj.columns) # type: ignore
 
         return self._run(ast)
 
